import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { ApiCall } from '../../services/api-call';
import { GetActivitiesFilters } from './modal/get-activities.interface';
import { GroupedAppInventory } from './modal/grouped-app-inventory.interface';
import { EntityBaseClass } from '../entity-base-class';
/**
 * Activities
 *
 * @export
 * @class Activities
 * @extends {EntityBaseClass}
 */
export declare class Activities extends EntityBaseClass {
    private apiCall;
    activitiesTypes: any;
    constructor(apiCall: ApiCall);
    /**
     *
     * Get activities types
     * GET : /web/api/v2.0/activities/types
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Activities
     */
    getActivityTypes(): Promise<SDKRespond>;
    /**
     * Get a list of activities.
     * GET : /web/api/v2.0/activities
     * @param {GetActivitiesFilters} [fiters]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Activities
     */
    get(fiters?: GetActivitiesFilters): Promise<SDKRespond>;
    /**
     * Get App Inventory
     *
     * GET : /web/api/v2.0/application-inventory
     * Retrieve application inventory grouped by Name, Publisher
     * @param {GroupedAppInventory} [filters]
     * @returns
     *
     * @memberOf Activities
     */
    getAppInventory(filters?: GroupedAppInventory): Promise<SDKRespond>;
    /**
     * Get App Inventory Count
     * GET: /web/api/v2.0/application-inventory-counts
     *
     * @param {GroupedAppInventory} [filters]
     * @returns
     *
     * @memberOf Activities
     */
    getAppInventoryCount(filters?: GroupedAppInventory): Promise<SDKRespond>;
    /**
     * Dowload Logs Files
     *
     * @param {string} agentId
     * @param {string} activityId
     * @param {string} [destination]
     *
     * @memberOf Activities
     */
    dowloadLogsFiles(agentId: string, activityId: string, destination?: string): Promise<void>;
}
