import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { ApiCall } from '../../services/api-call';
import { EntityBaseClass } from '../entity-base-class';
import { AgentActionsRequest } from './modal/agent-actions.interface';
import { GetAgentRequest } from '../agent/modal/get-agents.interface';
/**
 * Agent Actions
 *
 * @export
 * @class AgentActions
 * @extends {EntityBaseClass}
 */
export declare class AgentActions extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get() = Fetch logs()
     *
     * @param {GetAgentRequest} filters
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    get(filters: GetAgentRequest): Promise<SDKRespond>;
    /**
     * Fetch logs
     *
     * Sends a "fetch logs" command to all agents matching the input filter.
     * This Method sends creation of log file to the agent
     * The final result is can be shown in Activities by getting a a link to logs files
     * it could take a while to this action to take place.
     *
     * POST : /web/api/v2.0/agents/actions/fetch-logs
     *
     * @param {GetAgentRequest} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    fetchLogs(filter?: GetAgentRequest): Promise<SDKRespond>;
    /**
     * Abort Scan
     *
     * Aborts running scan on all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/abort-scan
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    abortScan(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Approve Uninstall
     *
     * Approve uninstall requests for all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/approve-uninstall
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    approveUninstall(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Broadcast Message
     *
     * Broadcasts a message to all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/broadcast
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    broadcastMessage(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Connect to network - Sends a "connect to network" command to all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/connect
     * @param data : AgentActionsRequest
     */
    connectToNetwork(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Decommission
     *
     * Decommissions all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/decommission
     *
     * @param data : : AgentActionsRequest
     */
    decommission(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Disconnect From Network
     *
     *
     * Sends a "disconnect from network" command to all agents matching the input filter.
     * POST :  /web/api/v2.0/agents/actions/disconnect
     *
     * @param {AgentActionsRequest} data
     * @returns
     *
     * @memberOf AgentActions
     */
    disconnectFromNetwork(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Initial Scan
     *
     *  POST :  /web/api/v2.0/agents/actions/initiate-scan
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    initiateScan(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Move Specified Agents To Target Site
     *
     * Move specified agents to (default group of) target site
     * POST : /web/api/v2.0/agents/actions/move-to-site
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    moveSpecifiedAgentsToTargetSite(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Reject Uninstall
     *
     * Reject uninstall requests for all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/reject-uninstall
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    rejectUninstall(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Reset Local Config To Policy
     *
     * Reset policy overrides set by SentinelCtl for all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/reset-local-config
     *
     * @param {AgentActionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    resetLocalConfigToPolicy(data: AgentActionsRequest): Promise<SDKRespond>;
    /**
     * Reset
     *
     * Sends a restart command to all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/restart-machine
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    reset(data: any): Promise<SDKRespond>;
    /**
     * Set Persistent Configuration Overrides
     *
     * POST : /web/api/v2.0/agents/actions/set-config
     * Set persistent configuration overrides for all agents matching the input filter.
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    setPersistentConfigurationOverrides(data: any): Promise<SDKRespond>;
    /**
     * Shutdown
     *
     * Sends a shutdown command to all agents matching the input filter.
     * POST : /web/api/v2.0/agents/actions/shutdown
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    shutdown(data: any): Promise<SDKRespond>;
    /**
     * Uninstall
     *
     * POST : /web/api/v2.0/agents/actions/uninstall
     * Sends an uninstall command to all agents matching the input filter.
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    uninstall(data: any): Promise<SDKRespond>;
    /**
     * Update Software
     *
     * Send update software command to all agents matching the input filter.
     * POST: /web/api/v2.0/agents/actions/update-software
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    updateSoftware(data: any): Promise<SDKRespond>;
    /**
     * Fetch Files
     *
     * Fetch files from agents (up to 10MB per action)
     * POST : /web/api/v2.0/agents/{agent_id}/actions/fetch-files
     *
     * @param {*} data
     * @param {string} agentId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf AgentActions
     */
    fetchFiles(data: any, agentId: string): Promise<SDKRespond>;
}
