"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var dv2_entities_types_1 = require("./enums/dv2-entities-types");
var dv2_operators_types_1 = require("./enums/dv2-operators-types");
var custom_error_class_1 = require("../../errors/custom-error-class");
var BaseDV2Query = /** @class */ (function () {
    function BaseDV2Query() {
        this.query = '';
        this.queryID = '';
        this.currentStep = 0;
        this.isFullQuery = false;
    }
    BaseDV2Query.prototype.setFullQueryPart = function (Entity, operator, value, connectorOperator) {
        try {
            var result = this.setEntity(Entity)
                .setOperator(operator)
                .setValue(value, connectorOperator);
            return result;
        }
        catch (err) {
            throw err;
        }
    };
    BaseDV2Query.prototype.setQueryString = function (stringToAppend, connectorOperator) {
        if (this.currentStep === 1) {
            this.query += stringToAppend + " ";
        }
        else if (this.currentStep === 2) {
            this.query += " " + stringToAppend + " ";
        }
        else {
            this.query += connectorOperator ? "\"" + stringToAppend + "\" " + connectorOperator + " " : " \"" + stringToAppend + "\"  ";
        }
    };
    /**
     * Build Query
     *
     * @param {Dv2fieldsTypes} Entity
     * @param {dv2OperatorsTypes} [operators]
     * @returns
     *
     * @memberOf BaseDV2Query
     */
    BaseDV2Query.prototype.setEntity = function (Entity, operators) {
        this.currentStep++;
        switch (this.currentStep) {
            case 1:
                this.setQueryString(Entity);
                return {
                    query: this.getQuery,
                    setOperator: setOperator.bind(this),
                    operatorsAvailable: dv2_entities_types_1.DV2QueryFields[Entity]
                };
            case 2:
                this.setQueryString(operators);
                return { query: this.getQuery, setValue: setValue.bind(this) };
            default:
                this.currentStep = 0;
        }
        /**
         * Add Operator
         *
         * @param {dv2OperatorsTypes} peratorsTypes
         * @returns
         */
        function setOperator(operatorsTypes) {
            if (this.validateOperator(Entity, operatorsTypes)) {
                return this.setEntity(Entity, operatorsTypes);
            }
            else {
                return new Error('invalid ');
            }
        }
        /**
         * Add Value After Opertor
         *
         * @param {any} value
         * @param {('or' | 'and')} [connectorOperator]
         * @returns
         */
        function setValue(value, connectorOperator) {
            this.query = connectorOperator ? this.query + " \"" + value + "\" " + connectorOperator + " " : this.query + " \"" + value + "\"  ";
            this.currentStep++;
            this.currentStep = 0;
            this.isFullQuery = connectorOperator ? false : true;
            return connectorOperator ? { setEntity: this.setEntity.bind(this) } : { query: this.getQuery() };
        }
    };
    /**
     * Get opertors enum names
     * @returns { string[] }
     */
    BaseDV2Query.prototype.getOpertorsEnumNames = function () {
        return Object.keys(dv2_operators_types_1.dv2OperatorsTypes);
    };
    // /**
    //  * Get Name By Operator
    //  * @param {string} operator
    //  * @returns
    //  */
    // getNameByOperator(operator: string) {
    //   const OpertorsNames = this.getOpertorsEnumNames();
    //   OpertorsNames.forEach(element => {
    //     if (dv2OperatorsTypes[element] === operator) {
    //       console.log(element);
    //       return element;
    //     }
    //   });
    //   return false;
    // }
    BaseDV2Query.prototype.validateOperator = function (Entity, operators) {
        var filtered = dv2_entities_types_1.DV2QueryFields[Entity].filter(function (item) { return item === operators; });
        if (filtered.length > 0) {
            return true;
        }
        else {
            throw new custom_error_class_1.CustomErrorEntity({
                message: "Illegal operation on " + Entity + ".\nOnly those operation are available for this Entity Type: \t [" + dv2_entities_types_1.DV2QueryFields[Entity] + "]"
            });
        }
    };
    BaseDV2Query.prototype.clearQuery = function () {
        this.query = '';
        this.queryID = '';
        this.currentStep = 0;
    };
    BaseDV2Query.prototype.getQuery = function () {
        return this.isFullQuery
            ? { query: this.query, queryID: this.queryID, isFullQuery: this.isFullQuery }
            : new custom_error_class_1.CustomErrorEntity({ message: 'Not full Query' });
    };
    return BaseDV2Query;
}());
exports.BaseDV2Query = BaseDV2Query;
//# sourceMappingURL=base-dv-query.class.js.map