import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from '../../services/api-call';
import { DVRequestData } from './modal/dv-request-data.interface';
import { BaseDVQuery } from './base-dv-query.class';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
/**
 * Deep Visibility V1
 *
 * @export
 * @class DeepVisibility
 * @extends {EntityBaseClass}
 */
export declare class DeepVisibility extends EntityBaseClass {
    queryUtils: BaseDVQuery;
    constructor(apiCall: ApiCall);
    get(data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Event Seen On Network
     *
     * @param {string} uuid
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getEventSeenOnNetwork(uuid: string, data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Agent Seen On Network
     *
     * @param {string} uuid
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getAgentSeenOnNetwork(uuid: string, data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Process By Unique Key
     * Retrieve process information by process unique key
     *
     * GET: /web/api/v2.0/ioc/process-unique-key
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getProcessByUniqueKey(): Promise<SDKRespond>;
    /**
     * Get Events
     *
     * GET: /web/api/v2.0/ioc/events/process/seen-on-network
     * Retrieve Deep Visibility events seen on network time ranges
     *
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getEvents(data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Agents Drill Down
     *
     * GET: /web/api/v2.0/ioc/agents/{uuid}
     * Retrieve Deep Visibility events by agent
     *
     * @param {string} uuid
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getAgentsDrillDown(uuid: string, data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Unique Process By Agent
     *
     * GET: /web/api/v2.0/ioc/events/process/{uuid}
     * Retrieve Deep Visibility unique processes from query
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getUniqueProcessByAgent(data: any): Promise<SDKRespond>;
    /**
     * Get Events By Process
     *
     * GET: /web/api/v2.0/ioc/events/{process_unique_key}
     * Get all events created by process
     *
     * @param {string} processUniqueKey
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getEventsByProcess(processUniqueKey: string, data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Events Filtered
     *
     * GET: /web/api/v2.0/ioc/{projection}
     * Retrieve Deep Visibility events from query filtered by type
     *
     * @param {string} projection
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getEventsFiltered(projection: string, data: DVRequestData): Promise<SDKRespond>;
    /**
     * Get Agents Breakdown
     *
     * GET: /web/api/v2.0/ioc/agents
     * Retrieve Deep Visibility events by agents
     *
     * @param {string} uuid
     * @param {DVRequestData} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf DeepVisibility
     */
    getAgentsBreakdown(uuid: string, data: DVRequestData): Promise<SDKRespond>;
}
