"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var get_error_class_1 = require("../errors/get-error-class");
var ends_points_entitities_1 = require("../end-point-entitity/ends-points-entitities");
var create_error_class_1 = require("../errors/create-error-class");
var update_error_class_1 = require("../errors/update-error-class");
var delete_error_class_1 = require("../errors/delete-error-class");
/**
 * EntityBaseClass
 *
 * @export
 * @abstract
 * @class EntityBaseClass
 * @implements {BaseClass}
 */
var EntityBaseClass = /** @class */ (function () {
    function EntityBaseClass(endPoints, entityName, request) {
        this.request = request;
        this.endPoints = endPoints;
        this.entityName = entityName;
    }
    /**
     * Make Api Call
     *
     * this is implementation for apiCall.makeApiCall(...),
     * to be use on the extending class.
     * making the code much shorter and cleaner.
     *
     * There is two ways to send data :
     *  1. make an object by the method's interface
     *  2. RequestData<interface>(<data>)
     *
     * In addition we handel a case that
     *  - An additional data (like user_id) should be add to the url endpoint (see ApiUrlQueries inteface).
     *    In this case the url will be a function that accept the params needed to be added.
     *
     *
     * @param {string} endpointName
     * @param {*} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf EntityBaseClass
     */
    EntityBaseClass.prototype.makeApiCall = function (endpointName, data) {
        return __awaiter(this, void 0, void 0, function () {
            var req, postPreparedUrl, res, error_1, req, returnedError;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        _a.trys.push([0, 3, , 4]);
                        return [4 /*yield*/, ends_points_entitities_1.getEndPoint(this.entityName, endpointName)];
                    case 1:
                        req = _a.sent();
                        postPreparedUrl = this.attachQueryParamsIfNeeded(req.url, data);
                        this.deletePayloadQuery(data); // remove url's attached parmas from data send to the server
                        return [4 /*yield*/, this.request.makeApiCall(postPreparedUrl, req.method, data)];
                    case 2:
                        res = _a.sent();
                        return [2 /*return*/, res];
                    case 3:
                        error_1 = _a.sent();
                        req = ends_points_entitities_1.getEndPoint(this.entityName, endpointName);
                        returnedError = this.errorHandler(req.method, endpointName, error_1);
                        throw this.errorHandler(req.method, endpointName, returnedError);
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    /**
     * Error Handler
     *
     * used in makeApiCall method ,
     * Returns an Error by the HTTP METHOD TYPE (GET, POST ETC...)
     *
     * @param {HttpMethod} reqMethode
     * @param {any} endpointName
     * @param {any} error
     * @returns :
     * GetEntityError | CreateEntityError | UpdateEntityError | DeleteEntityError
     *
     * @memberOf EntityBaseClass
     */
    EntityBaseClass.prototype.errorHandler = function (reqMethode, endpointName, error) {
        switch (reqMethode) {
            case "get" /* GET */:
                return new get_error_class_1.GetEntityError(error, this.entityName, endpointName);
            case "post" /* POST */:
                return new create_error_class_1.CreateEntityError(error, this.entityName, endpointName);
            case "put" /* PUT */:
                return new update_error_class_1.UpdateEntityError(error, this.entityName, endpointName);
            case "delete" /* DELETE */:
                return new delete_error_class_1.DeleteEntityError(error, this.entityName, endpointName);
        }
    };
    /**
     * Prepare Api Url Queries
     *
     * this function returns an object with the SDKstandart's structure ,
     * so later on data will be added to the url
     *
     * Example: /web/api/v2.0/users/{user_id} (userId = "523"):
     *    1. userId is sent as a query param (can be in all rest types) in the api call
     *    2. userId is passed to prepareApiUrlQueries([userId])
     *       Retuns ApiUrlQueries { payloadQuery:["523"] } (for farther processing)
     *
     * @protected
     * @param {any[]} data
     * @returns {ApiUrlQueries}
     *
     * @memberOf EntityBaseClass
     */
    EntityBaseClass.prototype.prepareApiUrlQueries = function (data) {
        return {
            payloadQuery: data.slice()
        };
    };
    /**
     * Attach Query Params
     *
     * @private
     * @param {*} url
     * @param {*} data
     * @returns
     *
     * @memberOf EntityBaseClass
     */
    EntityBaseClass.prototype.attachQueryParams = function (url, data) {
        var extractQueryParams = function (queryData) { return (queryData.hasOwnProperty('payloadQuery') ? queryData.payloadQuery : ''); };
        var extractedParams = extractQueryParams(data);
        return url.apply(void 0, extractedParams);
    };
    /**
     * Attach Query Params If Needed
     *
     *  - called from makeApiCall
     *  - extract Query Params
     *  - attach it to the url by calling url() function
     *
     * @param url : any
     * @param data
     * Returns: new url with the appended data
     */
    EntityBaseClass.prototype.attachQueryParamsIfNeeded = function (url, data) {
        var reqIsFunction = typeof url === 'function';
        return reqIsFunction ? this.attachQueryParams(url, data) : url;
    };
    /**
     * Delete PayloadQuery
     * After appending the relavent data to the url we simply  remove it from the data object
     *
     * @param {any} data
     *
     * @memberOf EntityBaseClass
     */
    EntityBaseClass.prototype.deletePayloadQuery = function (data) {
        if (data && data.hasOwnProperty('payloadQuery')) {
            delete data.payloadQuery;
        }
    };
    return EntityBaseClass;
}());
exports.EntityBaseClass = EntityBaseClass;
//# sourceMappingURL=entity-base-class.js.map