import { EntityBaseClass } from '../entity-base-class';
import { ExclusionsWhiteItemGetRequest } from './modal/exclusions-white-item-get-request.interface';
import { ExclusionsCreateWhiteItem } from './modal/exclusions-create-white-item.interface';
import { ExclusionsUpdateItem } from './modal/exclusions-update-item.interface';
import { ExclusionItemsType } from './enums/exclustion-items-types';
import { ExclusionTypes } from './enums/exclusion-types';
import { ApiCall } from '../../services/api-call';
import { BaseScope } from '../../model/scope-get.interface';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
/**
 * Exclusions
 *
 * @export
 * @class Exclusions
 * @extends {EntityBaseClass}
 */
export declare class Exclusions extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get
     * Get Black List Items + Get White List Items
     *
     * @param {ExclusionsWhiteItemGetRequest} data
     * @returns {Promise<{ whiteItems: any; blackItems: any }>}
     *
     * @memberOf Exclusions
     */
    get(data?: ExclusionsWhiteItemGetRequest): Promise<{
        whiteItems: any;
        blackItems: any;
    }>;
    /**
     * Get Black List Items
     *
     * List all items matching the input filter
     * GET : /web/api/v2.0/restrictions
     *
     * @param {GetListItemsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    getBlackItems(data?: ExclusionsWhiteItemGetRequest): Promise<SDKRespond>;
    /**
     * Get White List Items
     *
     * GET: /web/api/v2.0/exclusions
     * List all exclusion items matching the input filter
     *
     * @param {GetListItemsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    getWhiteItems(data: ExclusionsWhiteItemGetRequest): Promise<SDKRespond>;
    /**
     * Create white item
     *
     * POST: /web/api/v2.0/exclusions
     * Create exclusion item matching the input filter
     *
     * @param {CreateListItemRequest} data
     * @param {BaseScope} filter
     * @param {boolean} tenant
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private setWhiteItem;
    /**
     * Set Black Item
     *
     * POST:/web/api/v2.0/restrictions
     * Create restriction item matching the input filter
     *
     * @param {CreateListItemRequest} data
     * @param {BaseScope} filter
     * @param {boolean} tenant
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private setBlackItem;
    /**
     * Create
     *
     * @param {CreateListItemRequest} data
     * @param {BaseScope} filter
     * @param {boolean} tenant
     * @param {ExclusionItemsType} itemType
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    create(data: ExclusionsCreateWhiteItem, filter: BaseScope, tenant: boolean, itemType: ExclusionItemsType): Promise<SDKRespond>;
    /**
     * Update Black Item
     *
     * PUT: /web/api/v2.0/restrictions
     * Update restriction item.
     *
     * @param {ExclusionsUpdateItem} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private updateBlackItem;
    /**
     * Update White Item
     *
     * PUT: /web/api/v2.0/exclusions
     * Update exclusion item.
     *
     * @param {ExclusionsUpdateItem} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private updateWhiteItem;
    /**
     * Update
     *
     * @param {ExclusionItemsType} itemType
     * @param {ExclusionsUpdateItem} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    update(itemType: ExclusionItemsType, data: ExclusionsUpdateItem): Promise<SDKRespond>;
    /**
     * Delete Black Item
     *
     * @param {string[]} ids
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private deleteBlackItem;
    /**
     * Delete White Item
     *
     * @private
     * @param {string[]} ids
     * @param {ExclusionTypes} type
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    private deleteWhiteItem;
    /**
     * Delete
     *
     * @param {string[]} ids
     * @param {ExclusionItemsType} itemType
     * @param {ExclusionTypes} [type]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Exclusions
     */
    delete(ids: string[], itemType: ExclusionItemsType, type?: ExclusionTypes): Promise<SDKRespond>;
}
