import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { GetFilterRequest } from './modal/get-filter-request.interface';
import { UpdateDvFilterRequest } from './modal/update-filter-dv-request.interface';
import { FilterAdditionalDataRequest } from './modal/additional-filter-data.interface';
import { CreateFilterRequest } from './modal/create-filter-data-request.interface';
import { CreateDvFilterRequest } from './modal/create-dv-filter-request.interface';
import { ScopeFilterAdditionalDataRequest } from './modal/scope-filter-data.interface';
/**
 * Filters
 *
 * @export
 * @class Filters
 * @extends {EntityBaseClass}
 */
export declare class Filters extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    get(data?: GetFilterRequest): Promise<SDKRespond>;
    /**
     * Get Filters
     *
     * Get a list of saved filters
     * GET: /web/api/v2.0/filters
     *
     * @param {GetFilterRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    getFilters(data: GetFilterRequest): Promise<SDKRespond>;
    /**
     * Get Dv Filter
     *
     * @param {GetFilterRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    getDvFilter(data?: GetFilterRequest): Promise<SDKRespond>;
    /**
     * Delete Dv Filter
     *
     * @param {string} filterId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    deleteDvFilter(filterId: string): Promise<SDKRespond>;
    /**
     * Delete Filter
     *
     * @param {string} filterId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    deleteFilter(filterId: string): Promise<SDKRespond>;
    /**
     * Save Dv Filter
     *
     * @param {CreateDvFilterRequest} data
     * @param {FilterAdditionalDataRequest} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    saveDvFilter(data: CreateDvFilterRequest, filter: FilterAdditionalDataRequest): Promise<SDKRespond>;
    /**
     * Save Filter
     *
     * @param {CreateFilterRequest} data
     * @param filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    saveFilter(data: CreateFilterRequest, filter?: ScopeFilterAdditionalDataRequest): Promise<SDKRespond>;
    /**
     * Update Dv Filters
     *
     * @param {string} filterId
     * @param {UpdateDvFilterRequest} data
     * @param {string} filterName
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    updateDvFilters(filterId: string, data: UpdateDvFilterRequest, filter: FilterAdditionalDataRequest): Promise<SDKRespond>;
    /**
     * Update Filter
     *
     * @param {UpdateDvFilterRequest} data
     * @param {FilterAdditionalDataRequest} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Filters
     */
    updateFilter(data: UpdateDvFilterRequest, filterId: string, filter?: FilterAdditionalDataRequest): Promise<SDKRespond>;
}
