import { SDKRespond } from '../../../services/modal/sdk-respond-interface';
import { ApiCall } from '../../../services/api-call';
import { EntityBaseClass } from '../../entity-base-class';
import { BaseScope } from '../../../model/scope-get.interface';
import { ForensicApplictionsConnectionsRequest } from './modal/forensic-applictions-get-connections-request.interface';
/**
 * Forensic Applictions
 *
 * @export
 * @class ForensicApplictions
 * @extends {EntityBaseClass}
 */
export declare class ForensicApplictions extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get = getApplicationForensicDetails(applictionId) + getApplicationForensics(applictionId)
     * GET : /web/api/v2.0/applications/{application_id}/forensics
     *
     * @param {string} applictionId
     * @returns {Promise<any>}
     *
     * @memberOf ForensicApplictions
     */
    get(applictionId: string): Promise<any>;
    /**
     * Get Application Forensic Details
     * GET: /web/api/v2.0/applications/{application_id}/forensics/details
     *
     * @param {string} applicationId
     * @param {BaseScope} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicApplictions
     */
    getApplicationForensicDetails(applicationId: string, data?: BaseScope): Promise<SDKRespond>;
    /**
     * Get Application Forensics - Get forensics data for the application.
     * GET: /web/api/v2.0/applications/{application_id}/forensics
     *
     * @param {string} applicationId
     * @param {BaseScope} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicApplictions
     */
    getApplicationForensics(applicationId: string, data?: BaseScope): Promise<SDKRespond>;
    /**
     * Get Application Connections
     * GET: /web/api/v2.0/applications/{application_id}/forensics/connections
     *
     * @param {string} applicationId
     * @param {ForensicApplictionsConnectionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicApplictions
     */
    getApplicationConnections(applicationId: string, data: ForensicApplictionsConnectionsRequest): Promise<SDKRespond>;
    /**
     * Export Application
     * GET : /web/api/v2.0/applications/{application_id}/forensics/export/{export_format}
     *
     * @param {string} applicationId
     * @param {ForensicApplictionsConnectionsRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicApplictions
     */
    exportApplication(applicationId: string, data: ForensicApplictionsConnectionsRequest): Promise<SDKRespond>;
}
