import { SDKRespond } from '../../../services/modal/sdk-respond-interface';
import { ApiCall } from '../../../services/api-call';
import { EntityBaseClass } from '../../entity-base-class';
import { ForensicThreatsConnectionsRequest } from './modal/threat-forensic-get-connection-request.interface';
import { BaseScope } from '../../../model/scope-get.interface';
import { ExportFormatsTypes } from '../enums/export-format.enum';
/**
 * Forensic Threat
 *
 * @export
 * @class ForensicThreat
 * @extends {EntityBaseClass}
 */
export declare class ForensicThreat extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get
     *
     * @param {string} threatId
     * @returns {Promise<any>}
     *
     * @memberOf ForensicThreat
     */
    get(threatId: string): Promise<any>;
    /**
     * Get Threat Forensic Details
     *
     * Get detailed forensics data for the threat
     * GET: /web/api/v2.0/threats/{threat_id}/forensics/details
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicThreat
     */
    getThreatForensicDetails(threatId: string): Promise<SDKRespond>;
    /**
     * Get Threat Forensics -   Get forensics data for the threat
     * GET : /web/api/v2.0/threats/{threat_id}/forensics
     *
     * @param {string} threatId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicThreat
     */
    getThreatForensics(threatId: string): Promise<SDKRespond>;
    /**
     * Get Threat Connections
     *
     * Get network connections for the threat
     * GET: /web/api/v2.0/threats/{threat_id}/forensics/connections
     *
     * @param {string} threatId
     * @param {ForensicThreatsConnectionsRequest} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicThreat
     */
    getThreatConnections(threatId: string, data?: ForensicThreatsConnectionsRequest): Promise<SDKRespond>;
    /**
     * Get Threat Seen On Network
     * GET: /web/api/v2.0/threats/{threat_id}/forensics/seenOnNetwork
     *
     * @param {string} threatId
     * @param {BaseScope} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicThreat
     */
    getThreatSeenOnNetwork(threatId: string, data?: BaseScope): Promise<SDKRespond>;
    /**
     * Export Threat
     *
     * Export threat with its events as csv/json/raw
     * GET: /web/api/v2.0/threats/{threat_id}/forensics/export/{export_format}
     * @param {string} threatId
     * @param {ExportFormatsTypes} export_format
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ForensicThreat
     */
    exportThreat(threatId: string, export_format: ExportFormatsTypes): Promise<SDKRespond>;
}
