import { EntityBaseClass } from '../entity-base-class';
import { BaseScope } from '../../model/scope-get.interface';
import { GroupRequestData } from './modal/group-request.interface';
import { Rank } from './modal/rank.interface';
import { MoveAgentGroup } from './modal/move-agent-request.interface';
import { SiteDefualtGroupRequest } from './modal/site-defualt-group-request.interface';
import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
/**
 * Group Class
 *
 * @export
 * @class Group
 * @extends {EntityBaseClass}
 */
export declare class Group extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get Groups
     *
     * Gets the group data.
     * GET : /web/api/v2.0/groups
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    get(data?: SiteDefualtGroupRequest): Promise<SDKRespond>;
    /**
     * Get Groups By Id
     *
     * Gets the group data.
     * GET : /web/api/v2.0/groups/{group_id}
     *
     * @param {string} groupId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    getGroupsById(groupId: string): Promise<SDKRespond>;
    /**
     * Get Default Groups for site
     * GET: /web/api/v2.0/private/groups-default
     *
     * @param {*} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    getDefaultGroups(filter?: SiteDefualtGroupRequest): Promise<SDKRespond>;
    /**
     * Get Global Policy
     *
     * GET: /web/api/v2.0/tenant/policy
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    getGlobalPolicy(): Promise<SDKRespond>;
    /**
     * Count Groups
     *
     * Gets count of groups per site.
     * GET : /web/api/v2.0/private/group-count
     *
     * @param {BaseScope} [scopeFilter]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    countGroups(scopeFilter?: BaseScope): Promise<SDKRespond>;
    /**
     * Revert Groups Policy
     *
     * PUT /web/api/v2.0/groups/{group_id}/revert-policy
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    revertGroupsPolicy(groupId: string, id?: string): Promise<SDKRespond>;
    /**
     * update - updateGroups
     *
     * PUT: /web/api/v2.0/groups/{group_id}
     * Updates the group data.
     *
     * @param {string} group_id
     * @param {GroupRequestData} group
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    update(group_id: string, group: GroupRequestData): Promise<SDKRespond>;
    /**
     * Update Ranks
     *
     * Update groups ranks.
     * PUT: /web/api/v2.0/groups/ranks
     *
     * @param {Rank[]} ranks
     * @param {BaseScope} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    updateRanks(ranks: Rank[], filter: BaseScope): Promise<SDKRespond>;
    /**
     * Move Agents
     *
     * @param {string} group_id
     * @param {MoveAgentGroup} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    moveAgents(group_id: string, filter: MoveAgentGroup): Promise<SDKRespond>;
    /**
     * Create
     *
     * Creates a new group.
     * POST: /web/api/v2.0/groups
     *
     * @param {GroupRequestData} group
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    create(group: GroupRequestData): Promise<SDKRespond>;
    /**
     * Delete Group - Deletes the group.
     * DELETE: /web/api/v2.0/groups/{group_id}
     *
     * @param {string} groupId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Group
     */
    delete(groupId: string): Promise<SDKRespond>;
}
