"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var api_call_1 = require("../../services/api-call");
var auth_service_1 = require("../../services/auth.service");
var threat_class_1 = require("../threat/threat.class");
var users_class_1 = require("../user/users.class");
var activity_class_1 = require("../activity/activity.class");
var agent_actions_class_1 = require("../agentAction/agent-actions.class");
var commamds_class_1 = require("../command/commamds.class");
var agent_1 = require("../agent/agent");
var site_class_1 = require("../site/site.class");
var system_class_1 = require("../system/system.class");
var policy_class_1 = require("../policy/policy.class");
var group_class_1 = require("../group/group.class");
var configOverride_class_1 = require("../config-override/configOverride.class");
var settings_class_1 = require("../settings/settings.class");
var update_class_1 = require("../update/update.class");
var deep_visibilty_v2_class_1 = require("../deep-visibility-v2/deep-visibilty-v2.class");
var filters_class_1 = require("../filters/filters.class");
var exclusion_class_1 = require("../exclusion/exclusion.class");
var report_class_1 = require("../report/report.class");
var hash_class_1 = require("../hash/hash.class");
var forensic_class_1 = require("../forensic/forensic.class");
var accounts_class_1 = require("../accounts/accounts.class");
var applications_risk_class_1 = require("../applications-risk/applications-risk.class");
var firewall_control_class_1 = require("../firewall-control/firewall-control.class");
var device_control_class_1 = require("../device-control/device-control.class");
var tags_class_1 = require("../tags/tags.class");
var custom_detection_rules_class_1 = require("../custom-detection-rules/custom-detection-rules.class");
var rbac_class_1 = require("../rbac/rbac.class");
var cred_group_class_1 = require("../auto-deploy/cred-group.class");
var cred_group_details_class_1 = require("../auto-deploy/cred-group-details.class");
/**
 * Management
 *
 * @export
 * @class Management
 * @implements {Managment}
 */
var Management = /** @class */ (function () {
    /**
     * Management class is Singleton ,
     * An Instance is created , only if one was never created before
     * else we returns the previous created instance
     * That's why 'getInstance' and  'instance' are statics
     * and the constructor is private (accessible only from 'getInstance' )
     * @param host
     * @param apiPath
     */
    function Management(host) {
        this.apiCall = api_call_1.ApiCall.getInstance(host);
        this.applicationsRisk = new applications_risk_class_1.ApplicationsRisk(this.apiCall);
        this.authenticator = new auth_service_1.Authenticator(this.apiCall);
        this.accounts = new accounts_class_1.Accounts(this.apiCall);
        this.threats = new threat_class_1.Threats(this.apiCall);
        this.users = new users_class_1.Users(this.apiCall);
        this.sites = new site_class_1.Sites(this.apiCall);
        this.system = new system_class_1.System(this.apiCall);
        this.policy = new policy_class_1.Policy(this.apiCall);
        this.groups = new group_class_1.Group(this.apiCall);
        this.commands = new commamds_class_1.Commands(this.apiCall);
        this.activities = new activity_class_1.Activities(this.apiCall);
        this.settings = new settings_class_1.Settings(this.apiCall, this.system);
        this.configOverride = new configOverride_class_1.ConfigOverRide(this.apiCall);
        this.filters = new filters_class_1.Filters(this.apiCall);
        this.reports = new report_class_1.Report(this.apiCall);
        this.hash = new hash_class_1.Hash(this.apiCall);
        this.exclusions = new exclusion_class_1.Exclusions(this.apiCall);
        this.deepVisibilityV2 = new deep_visibilty_v2_class_1.DeepVisibilityV2(this.apiCall);
        this.agents = new agent_1.Agents(this.apiCall);
        this.agentActions = new agent_actions_class_1.AgentActions(this.apiCall);
        this.forensics = new forensic_class_1.Forensic(this.apiCall);
        this.firewallControl = new firewall_control_class_1.FirewallControl(this.apiCall);
        this.deviceControl = new device_control_class_1.DeviceControl(this.apiCall);
        this.rbac = new rbac_class_1.RBAC(this.apiCall);
        this.tags = new tags_class_1.Tags(this.apiCall);
        this.customDetectionRules = new custom_detection_rules_class_1.CustomDetectionRules(this.apiCall);
        this.credGroup = new cred_group_class_1.CredGroup(this.apiCall);
        this.credGroupDetails = new cred_group_details_class_1.CredGroupDetails(this.apiCall);
        // ------------- Needs more work-> ----------------
        this.updates = new update_class_1.Update(this.apiCall); // not ready ! , need to test
    }
    Object.defineProperty(Management.prototype, "apiCall", {
        get: function () {
            return this._apiCall;
        },
        set: function (value) {
            this._apiCall = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Get Instance
     * Singleton implantation
     *
     * @static
     * @param {string} host
     * @param {string} apiPath
     * @returns
     *
     * @memberOf Management
     */
    Management.getInstance = function (host) {
        if (!Management.instance) {
            Management.instance = new Management(host);
        }
        return Management.instance;
    };
    return Management;
}());
exports.Management = Management;
//# sourceMappingURL=mangment.class.js.map