import { EntityBaseClass } from '../entity-base-class';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { PolicyDataRequest } from './modal/policy.interface';
import { ApiCall } from '../../services/api-call';
export declare class Policy extends EntityBaseClass {
    constructor(apiCall: ApiCall);
    /**
     * get()
     *
     * GET :  /web/api/v2.0/private/policy
     * Get a single policy
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    get(): Promise<SDKRespond>;
    /**
     * Get Policy
     *
     * @private
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    private getPolicyByScope;
    /**
     * Get Global Policy
     *
     * GET: /web/api/v2.0/tenant/policy
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    getGlobalPolicy(): Promise<SDKRespond>;
    /**
     * Get Group Policy
     * GET /web/api/v2.0/groups/${group_id}/policy
     * @param groupId
     */
    getGroupPolicy(groupId: string): Promise<SDKRespond>;
    /**
     * update/create
     *
     * There is no need for create function in policy due to the fact
     * That policies are linked to Entities (groups , sites etc..) , not created .
     *
     * @param {PolicyDataRequest} data
     * @param siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    update(data: PolicyDataRequest, siteId: string): Promise<SDKRespond>;
    /**
     * Update Group Policy
     *
     * @param {PolicyDataRequest} data
     * @param {string} group_id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Policy
     */
    updateGroupPolicy(data: PolicyDataRequest, group_id: string): Promise<SDKRespond>;
    /**
     * Update Tenant Policy
     *
     * PUT: /web/api/v2.0/tenant/policy
     * @param {PolicyDataRequest} data
     * @returns
     *
     * @memberOf Policy
     */
    updateTenantPolicy(data: PolicyDataRequest): Promise<SDKRespond>;
}
