import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { EntityBaseClass } from '../entity-base-class';
import { BaseScope } from '../../model/scope-get.interface';
/**
 * Users
 *
 * @export
 * @class Users
 * @extends {EntityBaseClass}
 */
export declare class RBAC extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get() = getAllRoles()
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    get(): Promise<SDKRespond>;
    /**
     * Create Role
     *
     * POST: /web/api/v2.0/rbac/role
     * @param {RoleRequest} createRoleReq
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    create(data: RoleRequest, filter?: Partial<BaseScope>): Promise<SDKRespond>;
    /**
     * Delete Role
     *
     * Deletes role by id.
     * Delete: /web/api/v2.0/rbac/role/{role_id}
     * @param {string} roleId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    delete(roleId: string): Promise<SDKRespond>;
    /**
     * Update Role
     *
     * Updates role by id.
     * PUT: /web/api/v2.0/rbac/role/{role_id}
     *
     * @param {string} id
     * @param {UpdateUserRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    update(role: RoleRequest, roleId: string): Promise<SDKRespond>;
    /**
     * Get All Roles
     * GET /web/api/v2.1/rbac/roles
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    getAllRoles(data?: any): Promise<SDKRespond>;
    /**
     * Get new role template
     * GET /web/api/v2.1/rbac/role
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf RBAC
     */
    getRoleTemplate(): Promise<SDKRespond>;
}
export interface RoleRequest {
    maxConcurrentSessions?: number;
    description: string;
    permissionIds: any[];
    name: string;
}
