import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from './../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { BaseGetReportRequest } from './modal/report-get-request.interface';
import { GetReportTaskRequest } from './modal/get-reports-task-request';
import { DeleteReportsRequest } from './modal/delete-reports-request.interface';
import { DeleteReportTask } from './modal/delete-reports-tasks.interface';
import { UpdateReportTaskRequest } from './modal/update-report-task.interface';
import { CreateReportsTaskRequest } from './modal/create-report-task-request.interface';
/**
 * Report
 *
 * @export
 * @class Report
 * @extends {EntityBaseClass}
 */
export declare class Report extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get Reports
     * GET: /web/api/v2.0/reports
     *
     * @param {BaseGetReportRequest} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    get(data?: BaseGetReportRequest): Promise<SDKRespond>;
    /**
     * Get Reports Task
     *
     * @param {GetReportTaskRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    getReportsTask(data: GetReportTaskRequest): Promise<SDKRespond>;
    /**
     * Get insight reports
     *
     * GET: /web/api/v2.0/reports/insights/types
     * Get the list of insight reports
     *
     * @param {string[]} groupIds
     * @param {string[]} siteIds
     * @param {boolean} forceUpdate
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    getInsightType(groupIds: string[], siteIds: string[], forceUpdate: boolean): Promise<SDKRespond>;
    /**
     * S1 RSS feed
     *
     * GET: /web/api/v2.0/sentinelonerss
     * Get sentinel RSS feed.
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    getRssFeed(): Promise<SDKRespond>;
    /**
     * Delete Reports
     *
     * @param {DeleteReportsRequest} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    deleteReports(filter: DeleteReportsRequest): Promise<SDKRespond>;
    /**
     * Delete Reports Task
     *
     * @param {DeleteReportTask} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    deleteReportsTask(filter: DeleteReportTask): Promise<SDKRespond>;
    /**
     * Update Report Task
     *
     * @param {string} taskId
     * @param {UpdateReportTaskRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    updateReportTask(taskId: string, data: UpdateReportTaskRequest): Promise<SDKRespond>;
    /**
     * Create Report Tasks
     *
     * @param {CreateReportsTaskRequest} data
     * @param {string[]} siteIds
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Report
     */
    createReportTasks(data: CreateReportsTaskRequest, siteIds?: string[]): Promise<SDKRespond>;
}
