import { EntityBaseClass } from '../../../entity-base-class';
import { SDKRespond } from '../../../../services/modal/sdk-respond-interface';
import { System } from '../../../system/system.class';
import { AdRolesStringsDataRequest } from './modal/ad-roles-strings-data-request.interface';
import { ActiveDirectoryRequest } from './modal/active-directory-data-request.interface';
import { BaseScope } from '../../../../model/scope-get.interface';
import { ApiCall } from '../../../../services/api-call';
/**
 * Active Directory
 *
 * @export
 * @class ActiveDirectory
 * @extends {EntityBaseClass}
 */
export declare class ActiveDirectory extends EntityBaseClass {
    private apiCall;
    private system;
    constructor(apiCall: ApiCall, system: System);
    /**
     * Get Active Directory Settings
     *
     * Gets the global Active Directory settings
     * GET : /web/api/v2.0/settings/active-directory
     *
     * @param {string} siteId
     * @param {boolean} tenant
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ActiveDirectory
     */
    get(siteId: string, tenant?: boolean): Promise<SDKRespond>;
    /**
     * Get AD Role String
     *
     * Gets the mappings of active directory FQDNs to user roles
     * GET : settings/active-directory/scope-mapping
     *
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ActiveDirectory
     */
    getADRoleString(siteId: string, tenant?: boolean): Promise<SDKRespond>;
    /**
     * Get AD If FeatureOn
     *
     * @private
     * @param {string} siteId
     * @returns
     *
     * @memberOf ActiveDirectory
     */
    private getADIfFeatureOn;
    /**
     * Set Active Directory Roles string
     *
     * Update site's active directory FQDNs
     * PUT: settings/active-directory/scope-mapping
     *
     * @param {(string[] | string)} sitesIds
     * @param {AdRolesStringsDataRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ActiveDirectory
     */
    setADRoleString(siteIds: string[] | string, data: AdRolesStringsDataRequest): Promise<SDKRespond>;
    /**
     * Set AD settings
     *
     * Update global Active Directory settings
     * PUT: settings/active-directory
     *
     * Before sending the request we check for :
     *  1. that the feature toogle is turned on
     *  2. that the data gave by the user passes the tests
     *
     * @param {ActiveDirectoryRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ActiveDirectory
     */
    setADsettings(data: ActiveDirectoryRequest): Promise<SDKRespond>;
    /**
     * Test AD Settings
     *
     * POST: settings/active-directory/test
     * Test active directory settings.
     * Before snding the request we check that feature toogle is turned on
     *
     * @param {ActiveDirectoryRequest} data
     * @param {BaseScope} sitesIds
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf ActiveDirectory
     */
    test(data: ActiveDirectoryRequest, sitesIds?: BaseScope): Promise<SDKRespond>;
}
