import { EntityBaseClass } from '../../../entity-base-class';
import { SDKRespond } from '../../../../services/modal/sdk-respond-interface';
import { SyslogDataRequest } from './modal/syslog-data-request.interface';
import { BaseScope } from '../../../../model/scope-get.interface';
import { ApiCall } from '../../../../services/api-call';
/**
 * SYSLOG
 *
 * @export
 * @class Syslog
 * @extends {EntityBaseClass}
 */
export declare class Syslog extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get SysLog settings
     *
     * GET : /web/api/v2.0/settings/syslog
     * Gets the site's SysLog settings.
     *
     * @param {(string[] | string)} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Syslog
     */
    get(siteId: string[] | string): Promise<SDKRespond>;
    /**
     * Test SYSLOG Settings
     * POST:  /web/api/v2.0/settings/syslog/test
     *
     * @param {SyslogDataRequest} settings
     * @param {BaseScope} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Syslog
     */
    test(settings: SyslogDataRequest, filter: BaseScope): Promise<SDKRespond>;
    /**
     * Set SYSLOG
     *
     * PUT : web/api/v2.0/settings/syslog
     * Update SysLog settings for site -
     * first test request is sent to the server
     *
     * @param {SyslogDataRequest} settings
     * @param {BaseScope} filter
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Syslog
     */
    set(settings: SyslogDataRequest, filter: BaseScope): Promise<SDKRespond>;
}
