import { EntityBaseClass } from '../../entity-base-class';
import { SDKRespond } from '../../../services/modal/sdk-respond-interface';
import { NotificationGetRequest } from './modal/notification-settings-request.interface';
import { NotificationRequest } from './modal/notification-data-request.interface';
import { NotificationRecipientsRequest } from './modal/notifiction-recipients-settings-request.interface';
import { ApiCall } from '../../../services/api-call';
export declare class Notifications extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get Notification Settings
     *
     * @param {string[]} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf NotificationSettings
     */
    get(siteId?: string): Promise<SDKRespond>;
    /**
     * Get SMS settings
     *
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf NotificationSettings
     */
    getSMSettings(siteId: string): Promise<SDKRespond>;
    /**
     * Get Recipients Settings
     *
     * Get Notification Recipients settings
     * GET : /web/api/v2.0/settings/recipients
     *
     * @param {NotificationGetRequest} Recipient
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Settings
     */
    getRecipientsBySite(Recipient?: NotificationGetRequest): Promise<SDKRespond>;
    /**
     * Delete Notification Recipient
     *
     * @param {string} Recipient
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf NotificationSettings
     */
    deleteNotificationRecipient(recipientId: string, Recipient?: NotificationGetRequest): Promise<SDKRespond>;
    /**
     * Set Notification Settings
     *
     * Update Notifications settings for site
     * PUT: /web/api/v2.0/settings/notifications
     *
     * @param {NotificationRequest} data
     * @param {string[]} sitIds
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Notifications
     */
    setNotificationSettings(data: NotificationRequest, sitIds: string[]): Promise<SDKRespond>;
    /**
     * Set Notification Recipients Settings
     *
     * PUT : /web/api/v2.0/settings/recipients
     * Update Notification Recipients for site
     *
     * @param {NotificationRecipientsRequest} data
     * @param {string[]} sitIds
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Notifications
     */
    setNotificationRecipientsSettings(data: NotificationRecipientsRequest, sitIds?: string[]): Promise<SDKRespond>;
    /**
     * Clear Pending Notification
     *
     * POST : settings/notifications/cancel-pending-emails
     * Clear (discard without sending) pending email notifications for the given scope
     *
     * @param {string[]} [siteIds]
     * @param {boolean} [tenant]
     * @returns
     *
     * @memberOf Notifications
     */
    clearPaddingNotification(siteIds?: string[] | string, tenant?: boolean): Promise<SDKRespond>;
}
