import { ApiCall } from '../../services/api-call';
import { EntityBaseClass } from '../entity-base-class';
import { PolicyDataRequest } from '../policy/modal/policy.interface';
import { CreateSiteRequest } from './modal/site-create.interface';
import { ReactiveSiteRequest } from './modal/reactive-site-request.interface';
import { CreateUserRequest } from '../user/modal/create-user-request';
import { UpdateSiteRequest } from './modal/update-site-request.interface';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { Site } from './modal/site-entetity.interface';
/**
 * Sites
 *
 * @export
 * @class Sites
 * @extends {EntityBaseClass}
 */
export declare class Sites extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get ( all sites )
     *
     * GET : /web/api/v2.0/sites
     * List all sites with filtering options
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    get(data?: Site): Promise<SDKRespond>;
    /**
     * Get By Id
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    getById(siteId: string): Promise<SDKRespond>;
    /**
     * Get Site Policy
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     * @memberOf Sites
     */
    getSitePolicy(siteId: string): Promise<SDKRespond>;
    /**
     * Expire Site
     *
     * Expire site now
     * POST: /web/api/v2.0/sites/{site_id}/expire-now
     *
     * @param {any} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    expireSite(siteId: any): Promise<SDKRespond>;
    /**
     * Create - creats's site
     *
     * @param {Site} site
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    create(site: CreateSiteRequest): Promise<SDKRespond>;
    /**
     * Regenerate Site Key
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    regenerateSiteKey(siteId: string): Promise<SDKRespond>;
    /**
     * Create With Admin
     *
     * POST  /web/api/v2.0/site-with-admin
     * @param {Site} site
     * @param {User} user
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    createWithAdmin(site: CreateSiteRequest, user: CreateUserRequest): Promise<SDKRespond>;
    /**
     * Revert Site Policy
     *
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    revertSitePolicy(siteId: string): Promise<SDKRespond>;
    /**
     * Update
     *
     * updates site
     * PUT /web/api/v2.0/sites/{site_id}te
     *
     * @param {Site} site
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    update(site: UpdateSiteRequest, siteId: string): Promise<SDKRespond>;
    /**
     * Update Site Policy
     *
     * @param {string} siteId
     * @param {Policy} policy
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    updateSitePolicy(siteId: string, policy: PolicyDataRequest): Promise<SDKRespond>;
    /**
     * Reactivate Site
     *
     * Reactivates an expired site
     * PUT : /web/api/v2.0/sites/{site_id}/reactivate
     *
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    reactivateSite(siteId: string, data: ReactiveSiteRequest): Promise<SDKRespond>;
    /**
     * Delete - delete site (by id)
     *
     * DELET : /web/api/v2.0/sites/{site_id}
     * @param {string} siteId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Sites
     */
    delete(siteId: string): Promise<SDKRespond>;
}
