import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { SetSystemConfigurionRequest } from './modal/set-system-configurtion-request.interface';
/**
 * System
 *
 * @export
 * @class System
 * @extends {EntityBaseClass}
 */
export declare class System extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get() = getSystemConfig()
     *
     * Get system config
     * GET : /web/api/v2.0/system/configuration
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf System
     */
    get(sitesIds?: string[]): Promise<SDKRespond>;
    /**
     * Get System Info
     * GET  /web/api/v2.0/system/info
     *
     * @returns
     *
     * @memberOf System
     */
    getSystemInfo(): Promise<SDKRespond>;
    /**
     * GetEnabledFeature
     *
     * @param {string[]} siteIds
     * List of Site IDs to filter by. Example: "225494730938493804,225494730938493915".
     * @returns
     *
     * @memberOf System
     */
    getEnabledFeature(siteIds?: string[]): Promise<SDKRespond>;
    /**
     * Update - setSystemConfig
     *
     * PUT  /web/api/v2.0/system/configuration
     * Update system configuration
     *
     * @returns
     *
     * @memberOf System
     */
    update(filter: {
        siteIds?: string[];
    }, data: SetSystemConfigurionRequest): Promise<SDKRespond>;
    /**
     * Get the system status
     *
     * GET : /web/api/v2.0/system/status
     *
     * @returns
     *
     * @memberOf System
     */
    getSystemSatus(): Promise<SDKRespond>;
}
