import { BaseScope } from '../../model/scope-get.interface';
import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { MitigateActions } from '../../enums/mitigate-actions';
import { CountByFilterPayload } from './modal/count-by-filter-payload.interface';
import { FillersTypes } from './modal/filters.interface';
import { GetThreatsGrouped } from './modal/get-threats-grouped.interface';
import { MarkAsBengin } from './modal/mark-as-bengin.interface';
import { MarkAsResolve } from './modal/mark-as-resolve.interface';
import { MarkAsThreat } from './modal/mark-as-threat.interface';
import { ThreatFilterPayload } from './modal/threat-filter-payload.interface';
import { EntityBaseClass } from '../entity-base-class';
import { NotePayload } from './modal/note-payload-interface.interface';
import { AddToBlacklistPayloadInterface } from './modal/add-to-blacklist-payload.interface';
/**
 * Threats
 *
 * @export
 * @class Threats
 * @extends {EntityBaseClass}
 */
export declare class Threats extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get  (threats)
     *
     * get threats using a variety of filters
     * GET : /web/api/v2.0/threats
     *
     * @param {Partial<GetThreatsGrouped>} [filters]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    get(filters?: Partial<GetThreatsGrouped>): Promise<SDKRespond>;
    /**
     * Count by filters
     *
     * Show a count of threats per filter
     * Get:/web/api/v2.0/private/threats/filters-count
     *
     * @param {CountByFilterPayload} [filters]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    countByFilters(filters?: CountByFilterPayload): Promise<SDKRespond>;
    /**
     * Get Threat Type Group
     *
     * GET: /web/api/v2.0/private/threat-groups.
     * returns extended threats data grouped by hash.
     *
     * @param {GetThreatsGrouped} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    getThreatGroup(data?: GetThreatsGrouped): Promise<SDKRespond>;
    /**
     * Get Threats Summery
     *
     * GET:/web/api/v2.0/private/threats/summary
     * Get dashboard threat summary
     * groupIds[] List of Group IDs to filter by. Example: "225494730938493804,225494730938493915".
     * sitesIds[] List of Site IDs to filter by. Example: "225494730938493804,225494730938493915".
     *
     * @param {BaseScope} scope
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    getThreatsSummery(scope: BaseScope): Promise<SDKRespond>;
    /**
     * Mitigate Thereat
     *
     * POST:/web/api/v2.0/threats/mitigate/{action}
     * Apply a mitigation action to a group of threats matching the input filter.
     *
     * @param {MitigateActions} action
     * @param {ThreatFilterPayload} body
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    mitigateThreat(action: MitigateActions, filter: ThreatFilterPayload): Promise<SDKRespond>;
    /**
     * Mark As Threat - Mark suspicious threats as threats.
     * Post : /web/api/v2.0/threats/mark-as-threat
     *
     * @param {MarkAsThreat} [data]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    markAsThreat(data?: MarkAsThreat): Promise<SDKRespond>;
    /**
     * Mark As Resolved
     *
     * Mark filtered threats as resolved.
     * Post: /web/api/v2.0/threats/mark-as-resolved
     *
     * @param {MarkAsResolve} body
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    markAsResolved(body: MarkAsResolve): Promise<SDKRespond>;
    /**
     * Mark As Benign
     *
     * Mark hashes as benign and threat as resolved.
     * Post:/web/api/v2.0/threats/mark-as-benign
     *
     * @param {MarkAsBengin} body
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    markAsBenign(body: MarkAsBengin): Promise<SDKRespond>;
    /**
     * Disable Engines
     *
     * POST /web/api/v2.0/threats/engines/disable
     * Disable list of engines.
     * @params body: ThreatFilterPayload
     *
     * @param {ThreatFilterPayload} body
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Threats
     */
    disableEngines(body: ThreatFilterPayload): Promise<SDKRespond>;
    /**
     * Add threat hash to blacklist.
     * Post: /web/api/v2.1/threats/add-to-blacklist
     * @param blacklistPayload
     */
    addToBlackList(blacklistPayload: AddToBlacklistPayloadInterface, filter: FillersTypes): Promise<SDKRespond>;
    /**
     * Add Note
     *
     * Add threat note
     * Post: /web/api/v2.0/private/threats/${threadId}/notes
     *
     * @param {string} threatId
     * @param {NotePayload} body
     * @returns {Promise<SDKRespond>}
     */
    addNote(note: NotePayload): Promise<SDKRespond>;
    /**
     * Get Notes
     *
     * Get threat notes
     * Post: /web/api/v2.0/private/threats/${threadId}/notes
     *
     * @param {string} threatId
     * @returns {Promise<SDKRespond>}
     */
    getNotes(threadId: string): Promise<SDKRespond>;
    /**
     * Edit Note
     *
     * Add threat note
     * Post: /web/api/v2.0/private/threats/${threadId}/notes
     *
     * @param {string} threatId
     * @param {NotePayload} body
     * @returns {Promise<SDKRespond>}
     */
    editNote(threadId: string, noteId: string, note: NotePayload): Promise<SDKRespond>;
    /**
     * Delete Note
     *
     * Add threat note
     * Post: /web/api/v2.0/private/threats/${threadId}/notes/${noteId}
     *
     * @param {string} threatId
     * @param {NotePayload} body
     * @returns {Promise<SDKRespond>}
     */
    deleteNote(threadId: string, noteId: string): Promise<SDKRespond>;
}
