import { EntityBaseClass } from '../entity-base-class';
import { ApiCall } from '../../services/api-call';
import { SDKRespond } from './../../services/modal/sdk-respond-interface';
import { CustomErrorEntity } from '../../errors/custom-error-class';
import { UploadAgentPackageModel } from './model/upload-agent-package.model';
/**
 * Update
 *
 * @export
 * @class Update
 * @extends {EntityBaseClass}
 */
export declare class Update extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * Get Latest Packages
     *
     * GET: /web/api/v2.0/update/agent/packages
     * List of all available agent packages
     *
     * @returns {Promise<SDKRespond | CustomErrorEntity>}
     *
     * @memberOf Update
     */
    get(): Promise<SDKRespond | CustomErrorEntity>;
    /**
     * Upload Package
     *
     * POST : /web/api/v2.0/upload/software
     * Upload a system software package
     *
     * @param {string} filePath
     * @param {string} fileName
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    uploadPackage(filePath: string, fileName: string): Promise<SDKRespond>;
    /**
     * Deploy system package
     *
     * POST: upload/software/deploy
     * Deploys a system software package, should be performed only after uploading a software
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    deploy(): Promise<SDKRespond>;
    /**
     * Delete
     *
     * Bulk delete existing packages
     * DELET: /web/api/v2.0/update/agent/packages
     *
     * @param {string[]} ids Package IDs to delete
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    delete(ids: string[]): Promise<SDKRespond>;
    /**
     * Upload Agent Package
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    uploadAgentPackage(data: UploadAgentPackageModel, filePath: string, filename: string): Promise<SDKRespond>;
    /**
     * Download Package
     *
     * GET: /web/api/v2.0/update/agent/download/{site_id}/{package_id}
     * Download a package by site_id and filename
     *
     * @param {string} site_id
     * @param {string} package_id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    downloadPackage(site_id: string, package_id: string): Promise<SDKRespond>;
    /**
     * Download Agent Package
     *
     * GET: web/api/v2.0/update/agent/download/{package_id}
     * Download a package by filename ?? (package_id?)
     *
     * @param {string} package_id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    downloadAgentPackage(package_id: string): Promise<SDKRespond>;
    /**
     * Update
     *
     * @param {*} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Update
     */
    update(data: any): Promise<SDKRespond>;
}
