import { ApiCall } from '../../services/api-call';
import { SDKRespond } from '../../services/modal/sdk-respond-interface';
import { CreateUserRequest } from './modal/create-user-request';
import { Enable2faAppRequest } from './modal/enable-2fa-app-request';
import { VerifyCodeRequest } from './modal/verify-code-request';
import { ChangePasswordRequest } from './modal/cahnge-password-request';
import { UpdateUserRequest } from './modal/update-user-request';
import { EntityBaseClass } from '../entity-base-class';
import { GenerateIframeTokenRequest } from './modal/generate-iframe-token-request';
/**
 * Users
 *
 * @export
 * @class Users
 * @extends {EntityBaseClass}
 */
export declare class Users extends EntityBaseClass {
    private apiCall;
    constructor(apiCall: ApiCall);
    /**
     * get() = getAllUsers()
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    get(): Promise<SDKRespond>;
    /**
     * Get Logged In User
     * GET: /web/api/v2.0/private/user-info
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    getLoggedInUser(): Promise<SDKRespond>;
    /**
     *
     * User Info
     *
     * Gets user info by id.
     * GET: /web/api/v2.0/private/user-info
     *
     * @param {string} [id]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    userInfo(id?: string): Promise<SDKRespond>;
    /**
     * Check Tenant Admin - Checks if logged in user is a tenant admin (must be logged in)
     * GET: /web/api/v2.0/users/tenant-admin-auth-check
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    checkTenantAdmin(): Promise<SDKRespond>;
    /**
     * Get User
     *
     * Gets a user by id.
     * GET :  /web/api/v2.0/users/{user_id}
     * @param {string} [user_id]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    getUserById(user_id: string): Promise<SDKRespond>;
    /**
     *  User By Token
     *
     *  Gets a user by token.
     *  GET: /web/api/v2.0/user
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    getUserByToken(): Promise<SDKRespond>;
    /**
     * Request TwoFa App
     *
     * Request 2FA app
     * POST: /web/api/v2.0/users/request-app
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    requestTwoFaApp(): Promise<SDKRespond>;
    /**
     * Generate Recovery Code
     *
     * POST: /web/api/v2.0/users/generate-recovery-codes
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    generateUserRecoveryCode(): Promise<SDKRespond>;
    /**
     * Generate Iframe Token
     *
     * POST: /web/api/v2.0/users/generate-iframe-token
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    generateIframeToken(generateIframeTokenReq: GenerateIframeTokenRequest): Promise<SDKRespond>;
    /**
     * Generate Api Token
     *
     * POST: /web/api/v2.0/users/generate-api-token
     * Returns the API token for the authenticated user.
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    generateUserApiToken(): Promise<SDKRespond>;
    /**
     * Create Users
     *
     * POST: /web/api/v2.0/users
     * @param {CreateUserRequest} createUserReq
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    create(createUserReq: CreateUserRequest): Promise<SDKRespond>;
    /**
     * Delete User
     *
     * Deletes an user by id.
     * Delete: /web/api/v2.0/users/{user_id}
     * @param {string} userId
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    delete(userId: string): Promise<SDKRespond>;
    /**
     * Update User
     *
     * Updates a user by id.
     * If no id provided , loggedin user id will be used
     * PUT: /web/api/v2.0/users/{user_id}
     *
     * @param {string} id
     * @param {UpdateUserRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    update(data: UpdateUserRequest, id?: string): Promise<SDKRespond>;
    /**
     * Disable TwoFa
     *
     * Disables 2FA for the user
     * POST : /web/api/v2.0/users/2fa/disable
     * @param {string} id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    disableTwoFa(id: string): Promise<SDKRespond>;
    /**
     * Enable Two Fa
     *
     * Enables 2FA for the user
     * POST : /web/api/v2.0/users/2fa/enable
     * @param {string} id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    enableTwoFa(id: string): Promise<SDKRespond>;
    /**
     * Revoke Api Token
     *
     * POST : /web/api/v2.0/users/revoke-api-token
     * @param {string} id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    revokeApiToken(id: string): Promise<SDKRespond>;
    /**
     * Change User Password
     *
     * POST : /web/api/v2.0/users/change-password
     * @param {ChangePasswordRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    changeUserPassword(data: ChangePasswordRequest): Promise<SDKRespond>;
    /**
     * Sing Eula
     *
     * Mark EULA agreement signed for user scopes
     * POST : /web/api/v2.0/users/auth/eula
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    singEula(): Promise<SDKRespond>;
    /**
     * Verify Email
     *
     * Send verification email
     * POST : /web/api/v2.0/users/send-verification-email
     *
     * @param {string} id
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    verifyEmail(id: string): Promise<SDKRespond>;
    /**
     * Verify Code
     *
     * Verify user code used for email verification.
     * POST : /web/api/v2.0/users/user-code-verification
     *
     * @param {VerifyCodeRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    verifyCode(data: VerifyCodeRequest): Promise<SDKRespond>;
    /**
     * Check Viewer Auth
     *
     * Checks if logged in user has viewer permissions
     * GET : /web/api/v2.0/users/viewer-auth-check
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    checkViewerAuth(): Promise<SDKRespond>;
    /**
     * Enable Two Fa App
     *
     * Enables 2FA for the user
     * POST : /web/api/v2.0/users/2fa/enable
     *
     * @param {Enable2faAppRequest} data
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    enableTwoFaApp(data: Enable2faAppRequest): Promise<SDKRespond>;
    /**
     * Get Api Token Details
     * GET /web/api/v2.0/users/{user_id}/api-token-details
     * If no userId provided , the data returns will be of the current loggedin user
     *
     * @param {string} [user_id]
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    getApiTokenDetails(user_id?: string): Promise<SDKRespond>;
    /**
     * Get All Users
     * GET /web/api/v2.0/users
     *
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Users
     */
    getAllUsers(): Promise<SDKRespond>;
    /**
     * Enroll users for 2FA setup.
     *
     * POST /web/api/v2.1/users/enroll-2fa
     * @param userIds
     *
     * @returns {Promise<SDKRespond>}
     */
    enroll2fa(userIds: string[]): Promise<SDKRespond>;
    /**
     * trigger Reset Password On Next Login for users
     *
     * POST /web/api/v2.1/users/login/reset-password-on-next-login
     * @param userIds
     *
     * @returns {Promise<SDKRespond>}
     */
    triggerResetPasswordOnNextLogin(userIds: string[]): Promise<SDKRespond>;
    /**
     * Get Defualt Logged In User Props
     *
     * @private
     * @param {*} passedParams
     * @param {string[]} [requieredFields]
     * @returns
     *
     * @memberOf Users
     */
    private getDefualtLoggedInUserProps;
}
