import { HttpMethod } from '../enums/http-method';
import { SDKRespond } from './modal/sdk-respond-interface';
export declare class ApiCall {
    private hostName;
    private static instance;
    private _token;
    private _authMethod;
    private _isAuthenticated;
    private _isHttps;
    private constructor();
    /**
     * Get Instance
     * apiCall is Singleton
     *
     * @param hostName
     * @param apiPath
     */
    static getInstance(hostName: string): ApiCall;
    /**
     * Make Api Call
     *
     *  this is the most important function (exposed for the user)
     *  it summarize all action done by the SDKApiCall wrapper.
     *  1. we have agreed for a specific respond structure to be return for each call ,
     *     that is in order to get full information of both Request , Respond , and apiCall's Status
     *  2.there is Auth validation ,
     *    - if user is already logged in auth header is attached to the req
     *    - else no header is attached
     *  3. data attached to the req bu the method (Get request is attached by 'query string' etc)
     *  4. the respond from the call is attached to the requestData property (off the , same as other params
     *  5. SDKRespond is returned as a Promise
     *
     * @param urlSuffix
     * @param requestMethod
     * @param data
     */
    makeApiCall(urlSuffix: string, requestMethod: HttpMethod, data?: any): Promise<SDKRespond>;
    /**
     * Extract Respond
     *
     * validate that server respond is valid , before parsing it
     * @private
     * @param {any} response
     * @returns
     *
     * @memberOf ApiCall
     */
    private extractRespond;
    /**
     * Set Auth Header
     * @param authData
     * @param token
     */
    setAuthHeader(authData?: any, token?: string): object | void;
    /**
     * Extract Auth Method
     * @param authData
     */
    private extractAuthMethod;
    /**
     * Set Headers
     * @param _token
     * @param data
     * @param contentType
     */
    private setHeaders;
    /**
     * Wrap Api Call
     * @param endPoint
     * @param method
     * @param data
     */
    private wrapApiCall;
    /**
     * Build SDK Respond
     * @param url
     * @param reqMethod
     * @param data
     */
    private buildSDKRespond;
    /**
     * Build Url
     * @param url
     * @param method
     * @param data
     */
    private buildUrl;
    /**
     * Add Body Request
     * @param method
     * @param data
     * @param respond
     */
    private addBodyRequest;
    /**
     * Set Respond Data
     * @param wrappedApi
     * @param result : SDKRespond
     */
    private setRespond;
    /**
     * Get Authorization Header
     * returns {Authentication: string}
     */
    private getAuthorizationHeader;
    /**
     * Set Is Authenticated
     * @param _isAuth :boolean
     */
    private setIsAuthenticated;
    /**
     * Get Is Authenticated
     * return boolean
     */
    private getIsAuthenticated;
    /**
     * Set _token
     * @param token
     */
    private setToken;
    /**
     * Get _token Method
     * return _authMethod
     */
    private getTokenMethod;
    /**
     * Set Auth Method
     * @param authMethod : _authMethodType
     */
    private setAuthMethod;
    /**
     * Set Auth
     * @param _token
     * @param _authMethod
     */
    private setAuth;
    /**
     * Set Content Type Header
     * @param contentType
     * @param data request options
     */
    private setContentTypeHeader;
    /**
     * Get _token
     * return string | null
     */
    getToken(): string;
    /**
     * Extract Data Respond
     * checks if the api respond has multiple values
     *  - if true :
     *    - return all res as an array
     *   else:
     *    - check if there any value at all that came back from the server
     *         True - meaning a single value has returned
     *         False - returns the respond data as is
     * @param results
     */
    getRespondData(results: SDKRespond): any;
}
