import { ApiCall } from './api-call';
import { SDKRespond } from './modal/sdk-respond-interface';
import * as AuthEndPoints from '../end-point-entitity/authenticator-endpoints';
import { AuthRequest } from './modal/auth-request-interface';
/**
 * Authenticator
 *
 * @export
 * @class Authenticator
 */
export declare class Authenticator {
    private apiCall;
    endPoints: typeof AuthEndPoints.AuthenticatorEndPointTypes;
    entityName: string;
    private _isAuth;
    isAuth: boolean;
    constructor(apiCall: ApiCall);
    /**
     * Auth
     *
     * @param {AuthRequest} auth
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    authenticate(auth: AuthRequest): Promise<SDKRespond>;
    /**
     * login By User Password
     *
     * @private
     * @param {*} authData
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    private loginByUserPass;
    /**
     * Auth By Recovery Code
     *
     * authenticate user using a recovery code
     * POST: /web/api/v2.0/users/authenticate/recovery-code
     *
     * @private
     * @param {string} code
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    private loginByRecoveryCode;
    /**
     *  Login By Token
     *
     *  Logs in by API token
     *  POST: /users/login/by-api-token
     *
     * @private
     * @param {string} token
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    private loginByToken;
    /**
     * Login By Api Token
     * GET: /web/api/v2.0/users/login/by-token
     *
     * @private
     * @param {string} apiToken
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    private loginByApiToken;
    /**
     * authenticate with app
     *
     * POST : /web/api/v2.0/users/authenticate/app
     * @param code : string
     */
    private authWithApp;
    /**
     * Build Login Params
     *
     * @param username
     * @param password
     */
    private buildLoginParams;
    /**
     * Post Authentication
     *
     * @param {SDKRespond} res
     *
     * @memberOf Authenticator
     */
    private postAuthentication;
    /**
     * Logout
     *
     * POST: /web/api/v2.0/users/logout
     * @returns {Promise<SDKRespond>}
     *
     * @memberOf Authenticator
     */
    logout(): Promise<SDKRespond>;
}
